==> PDFlib-Lite-6.0.2.tar.gz: PDFlib-Lite-6.0.2/libs/pdflib/p_jpx.c <==
/*---------------------------------------------------------------------------*
 |              PDFlib - A library for generating PDF on the fly             |
 +---------------------------------------------------------------------------+
 | Copyright (c) 1997-2005 Thomas Merz and PDFlib GmbH. All rights reserved. |
 +---------------------------------------------------------------------------+
 |                                                                           |
 |    This software is subject to the PDFlib license. It is NOT in the       |
 |    public domain. Extended versions and commercial licenses are           |
 |    available, please check http://www.pdflib.com.                         |
 |                                                                           |
 *---------------------------------------------------------------------------*/

/* $Id: p_jpx.c,v 1.1.2.14 2005/06/08 19:59:02 tm Exp $
 *
 * JPEG2000 processing for PDFlib
 *
 */

#include "p_intern.h"
#include "p_color.h"
#include "p_image.h"

#ifndef PDF_JPX_SUPPORTED

pdc_bool
pdf_is_JPX_file(PDF *p, pdc_file *fp)
{
    (void) p;
    (void) fp;

    return pdc_false;
}

int
pdf_process_JPX_data(
    PDF *p,
    int imageslot)
{
    (void) imageslot;

    pdc_warning(p->pdc, PDF_E_UNSUPP_IMAGE, "JPEG2000", 0, 0, 0);
    return -1;
}

#else


pdc_bool
pdf_is_JPX_file(PDF *p, pdc_file *fp)
{
    (void) p;
    (void) fp;

    return pdc_false;
}

int
pdf_process_JPX_data(
    PDF *p,
    int imageslot)
{
    (void) imageslot;

    pdc_warning(p->pdc, PDF_E_UNSUPP_IMAGE, "JPEG2000", 0, 0, 0);
    return -1;
}



#endif /* PDF_JPX_SUPPORTED */

==> PDFlib-Lite-7.0.0.tar.gz: PDFlib-Lite-7.0.0/libs/pdflib/p_jpx.c <==
/*---------------------------------------------------------------------------*
 |              PDFlib - A library for generating PDF on the fly             |
 +---------------------------------------------------------------------------+
 | Copyright (c) 1997-2006 Thomas Merz and PDFlib GmbH. All rights reserved. |
 +---------------------------------------------------------------------------+
 |                                                                           |
 |    This software is subject to the PDFlib license. It is NOT in the       |
 |    public domain. Extended versions and commercial licenses are           |
 |    available, please check http://www.pdflib.com.                         |
 |                                                                           |
 *---------------------------------------------------------------------------*/

/* $Id: p_jpx.c,v 1.11 2006/09/14 11:47:49 kurt Exp $
 *
 * JPEG2000 processing for PDFlib
 *
 */

#include "p_intern.h"
#include "p_color.h"
#include "p_image.h"

#ifndef PDF_JPX_SUPPORTED

pdc_bool
pdf_is_JPX_file(PDF *p, pdc_file *fp)
{
    (void) p;
    (void) fp;

    return pdc_false;
}

int
pdf_process_JPX_data(
    PDF *p,
    int imageslot)
{
    pdf_image *image = &p->images[imageslot];

    pdc_set_errmsg(p->pdc, PDF_E_UNSUPP_IMAGE, "JPEG2000", 0, 0, 0);

    if (image->verbose)
        pdc_error(p->pdc, -1, 0, 0, 0, 0);

    return -1;
}

#else


pdc_bool
pdf_is_JPX_file(PDF *p, pdc_file *fp)
{
    (void) p;
    (void) fp;

    return pdc_false;
}

int
pdf_process_JPX_data(
    PDF *p,
    int imageslot)
{
    pdf_image *image = &p->images[imageslot];

    pdc_set_errmsg(p->pdc, PDF_E_UNSUPP_IMAGE, "JPEG2000", 0, 0, 0);

    if (image->verbose)
        pdc_error(p->pdc, -1, 0, 0, 0, 0);

    return -1;
}



#endif /* PDF_JPX_SUPPORTED */
